@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <iostream>
@@ -41,6 +40,7 @@ string event_type2str(t_event_type t) {
 	case EV_ASYNC_RESPONSE:	return "EV_ASYNC_RESPONSE";
 	case EV_BROKEN_CONNECTION: return "EV_BROKEN_CONNECTION";
 	case EV_TCP_PING:	return "EV_TCP_PING";
+	case EV_FN_CALL:	return "EV_FN_CALL";
 	}
 
 	return "UNKNOWN";
@@ -384,7 +384,7 @@ void t_event_ui::set_codec(t_audio_codec _codec) {
 	codec = _codec;
 }
 
-void t_event_ui::set_dtmf_event(char _dtmf_event) {
+void t_event_ui::set_dtmf_event(t_dtmf_ev _dtmf_event) {
 	dtmf_event = _dtmf_event;
 }
 
