@@ -2,19 +2,12 @@
 #define OSD_H
 #include <QObject>
 #include <QString>
-#if 0 //QT_VERSION >= 0x050000
-#	define OSD_VIEWCLASS QQuickView
-#	define QML_ITEMTYPE QQuickItem
-#else
-#	define OSD_VIEWCLASS QDeclarativeView
-#	define QML_ITEMTYPE QDeclarativeItem
-#endif
 
 // Must use forward declaration, otherwise build fails
 // due to double QMetaTypeID<QAction*> definition (wtf).
 // Hence I also cannot inherit from OSD_VIEWCLASS...
-class OSD_VIEWCLASS;
-class QML_ITEMTYPE;
+class QQuickView;
+class QQuickItem;
 
 class OSD : public QObject
 {
@@ -46,10 +39,10 @@ signals:
 	void muteClicked();
 
 private:
-	OSD_VIEWCLASS* m_view;
-	QML_ITEMTYPE* m_caller;
-	QML_ITEMTYPE* m_time;
-	QML_ITEMTYPE* m_mute;
+	QQuickView* m_view;
+	QQuickItem* m_caller;
+	QQuickItem* m_time;
+	QQuickItem* m_mute;
 };
 
 #endif // OSD_H
