@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <QPixmap>
@@ -29,6 +28,7 @@
 #include "twinkle_config.h"
 #include <QRegExp>
 #include <QValidator>
+#include <QRegExpValidator>
 #include "syssettingsform.h"
 /*
  *  Constructs a SysSettingsForm as a child of 'parent', with the
@@ -396,7 +396,8 @@ void SysSettingsForm::validate()
     for (int i = 0; i < profileListView->count(); i++)
     {
         QListWidgetItem *item = profileListView->item(i);
-        start_user_profiles.push_back(item->text().toStdString());
+		if (item->checkState() == Qt::Checked)
+			start_user_profiles.push_back(item->text().toStdString());
 	}
 	sys_config->set_start_user_profiles(start_user_profiles);
 	
