@@ -12,8 +12,7 @@
     GNU General Public License for more details.
     
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 #include <QPixmap>
 #include <QList>
@@ -32,6 +31,7 @@
 #include <QStringList>
 #include "twinkle_config.h"
 #include <QListWidget>
+#include <QRegExpValidator>
 #include "numberconversionform.h"
 #include "util.h"
 #include "userprofileform.h"
@@ -543,6 +543,7 @@ void UserProfileForm::populate()
 	transferConsultInprogCheckBox->setChecked(
 			current_profile->get_allow_transfer_consultation_inprog());
 	pPreferredIdCheckBox->setChecked(current_profile->get_send_p_preferred_id());
+	pAssertedIdCheckBox->setChecked(current_profile->get_send_p_asserted_id());
 	
 	// Transport/NAT
 	switch (current_profile->get_sip_transport()) {
@@ -596,7 +597,7 @@ void UserProfileForm::populate()
     conversionListView->setRowCount(conversions.size());
 
     int j = 0;
-    for (list<t_number_conversion>::reverse_iterator i = conversions.rbegin(); i != conversions.rend(); i++, j++)
+    for (list<t_number_conversion>::iterator i = conversions.begin(); i != conversions.end(); i++, j++)
 	{
         QTableWidgetItem* item = new QTableWidgetItem(QString::fromStdString(i->re));
         conversionListView->setItem(j, 0, item);
@@ -707,9 +708,9 @@ list<t_number_conversion> UserProfileForm::get_number_conversions()
 		t_number_conversion c;
 		
 		try {
-            item = conversionListView->item(0, 0);
+            item = conversionListView->item(i, 0);
             c.re.assign(item->text().toStdString());
-            item = conversionListView->item(0, 1);
+            item = conversionListView->item(i, 1);
             c.fmt = item->text().toStdString();
 			conversions.push_back(c);
         } catch (std::regex_error) {
@@ -1164,6 +1165,7 @@ bool UserProfileForm::validateValues()
 	current_profile->set_allow_transfer_consultation_inprog(
 			transferConsultInprogCheckBox->isChecked());
 	current_profile->set_send_p_preferred_id(pPreferredIdCheckBox->isChecked());
+	current_profile->set_send_p_asserted_id(pAssertedIdCheckBox->isChecked());
 	
 	// Transport/NAT
     switch (sipTransportComboBox->currentIndex()) {
