@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <assert.h>
@@ -38,7 +37,46 @@ t_call_info::t_call_info() {
 	clear();
 }
 
+t_call_info::t_call_info(const t_call_info& that) {
+	*this = that;
+}
+
+t_call_info& t_call_info::operator=(const t_call_info& that) {
+	if (this != &that) {
+		// FIXME: This may deadlock if "a=b" and "b=a" are run in
+		//        parallel.  The proper solution would be to switch
+		//        to std::mutex and call std::lock(this,that).
+		t_mutex_guard x1(that.mutex);
+		t_mutex_guard x2(this->mutex);
+
+		from_uri = that.from_uri;
+		from_display = that.from_display;
+
+		from_display_override = that.from_display_override;
+
+		from_organization = that.from_organization;
+		to_uri = that.to_uri;
+		to_display = that.to_display;
+		to_organization = that.to_organization;
+		subject = that.subject;
+		dtmf_supported = that.dtmf_supported;
+		dtmf_inband = that.dtmf_inband;
+		dtmf_info = that.dtmf_info;
+		hdr_referred_by = that.hdr_referred_by;
+
+		last_provisional_reason = that.last_provisional_reason;
+
+		send_codec = that.send_codec;
+		recv_codec = that.recv_codec;
+		refer_supported = that.refer_supported;
+	}
+
+	return *this;
+}
+
 void t_call_info::clear(void) {
+	t_mutex_guard g(mutex);
+
 	from_uri.set_url("");
 	from_display.clear();
 	from_display_override.clear();
@@ -56,6 +94,8 @@ void t_call_info::clear(void) {
 }
 
 string t_call_info::get_from_display_presentation(void) const {
+	t_mutex_guard g(mutex);
+
 	if (from_display_override.empty()) {
 		return from_display;
 	} else {
@@ -599,6 +639,7 @@ void t_line::invite(t_phone_user *pu, const t_url &to_uri, const string &to_disp
 	phone_user = pu;
 	t_user *user_config = pu->get_user_profile();
 
+	call_info.mutex.lock();
 	call_info.from_uri = create_user_uri(); // NOTE: hide_user is not set yet
 	call_info.from_display = user_config->get_display(false);
 	call_info.from_organization = user_config->get_organization();
@@ -607,6 +648,7 @@ void t_line::invite(t_phone_user *pu, const t_url &to_uri, const string &to_disp
 	call_info.to_organization.clear();
 	call_info.subject = subject;
 	call_info.hdr_referred_by = hdr_referred_by;
+	call_info.mutex.unlock();
 	
 	try_to_encrypt = user_config->get_zrtp_enabled();
 
@@ -658,7 +700,7 @@ void t_line::reject(void) {
 	stop_timer(LTMR_NO_ANSWER);
 
 	try {
-		active_dialog->reject(R_603_DECLINE);
+		active_dialog->reject(R_486_BUSY_HERE);
 	}
 	catch (t_exception x) {
 		// TODO: there is no call to reject
@@ -1452,6 +1494,7 @@ void t_line::recvd_invite(t_phone_user *pu, t_request *r, t_tid tid, const strin
 		user_config = phone_user->get_user_profile();
 		user_defined_ringtone = ringtone;
 		
+		call_info.mutex.lock();
 		call_info.from_uri = r->hdr_from.uri;
 		call_info.from_display = r->hdr_from.display;
 		call_info.from_display_override = r->hdr_from.display_override;
@@ -1464,6 +1507,7 @@ void t_line::recvd_invite(t_phone_user *pu, t_request *r, t_tid tid, const strin
 		call_info.to_display = r->hdr_to.display;
 		call_info.to_organization.clear();
 		call_info.subject = r->hdr_subject.subject;
+		call_info.mutex.unlock();
 		
 		try_to_encrypt = user_config->get_zrtp_enabled();
 
