@@ -12,15 +12,14 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 // RFC 3323
 // Privacy header
 
 #ifndef _H_HDR_PRIVACY
-#define _H_HDR_PRICACY
+#define _H_HDR_PRIVACY
 
 #include <list>
 #include <string>
