@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <assert.h>
@@ -721,7 +720,6 @@ void t_phone::handle_response_out_of_dialog(StunMessage *r, t_tuid tuid) {
 }
 
 t_phone_user *t_phone::find_phone_user(const string &profile_name) const {
-	t_rwmutex_reader x(phone_users_mtx);
 
 	for (list<t_phone_user *>::const_iterator i = phone_users.begin();
 	     i != phone_users.end(); ++i)
@@ -738,7 +736,6 @@ t_phone_user *t_phone::find_phone_user(const string &profile_name) const {
 }
 
 t_phone_user *t_phone::find_phone_user(const t_url &user_uri) const {
-	t_rwmutex_reader x(phone_users_mtx);
 
 	for (list<t_phone_user *>::const_iterator i = phone_users.begin();
 		     i != phone_users.end(); ++i)
