@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "twinkle_config.h"
@@ -195,10 +194,10 @@ t_win_geometry::t_win_geometry(const string &value) {
 	vector<string> v = split(value, ',');
 	
 	if (v.size() == 4) {
-		x = atoi(v[0].c_str());
-		y = atoi(v[1].c_str());
-		width = atoi(v[2].c_str());
-		height = atoi(v[3].c_str());
+		x = std::stoi(v[0]);
+		y = std::stoi(v[1]);
+		width = std::stoi(v[2]);
+		height = std::stoi(v[3]);
 	}
 }
 
@@ -1126,8 +1125,8 @@ string t_sys_settings::get_product_date(void) const {
 	vector<string> l = split(PRODUCT_DATE, ' ');
 	assert(l.size() == 3);
 	t.tm_mon = str2month_full(l[0]);
-	t.tm_mday = atoi(l[1].c_str());
-	t.tm_year = atoi(l[2].c_str()) - 1900;
+	t.tm_mday = std::stoi(l[1]);
+	t.tm_year = std::stoi(l[2]) - 1900;
 	
 	char buf[64];
 	strftime(buf, 64, "%d %B %Y", &t);
