@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include <iostream>
@@ -1001,7 +1000,7 @@ void t_userintf::do_dtmf(const string &digits) {
 	if (!call_info.dtmf_supported) return;
 	
 	for (string::const_iterator i = digits.begin(); i != digits.end(); i++) {
-		if (VALID_DTMF_SYM(*i)) {
+		if (is_valid_dtmf_sym(*i)) {
 			phone->pub_send_dtmf(*i, call_info.dtmf_inband, call_info.dtmf_info);
 		}
 	}
@@ -1566,7 +1565,7 @@ void t_userintf::do_help(const list<t_command_arg> &al) {
 		cout << "Usage:\n";
 		cout << "\treject\n";
 		cout << "Description:\n";
-		cout << "\tReject an incoming call. A 603 Decline response\n";
+		cout << "\tReject an incoming call. A 486 Busy Here response\n";
 		cout << "\twill be sent.\n";
 		cout << endl;
 
@@ -2939,13 +2938,13 @@ void t_userintf::cb_stop_call_notification(int line) {
 	cb_stop_tone(line);
 }
 
-void t_userintf::cb_dtmf_detected(int line, char dtmf_event) {
+void t_userintf::cb_dtmf_detected(int line, t_dtmf_ev dtmf_event) {
 	if (line >= NUM_USER_LINES) return;
 	
 	cout << endl;
 	cout << "Line " << line + 1 << ": DTMF detected: ";
 
-	if (VALID_DTMF_EV(dtmf_event)) {
+	if (is_valid_dtmf_ev(dtmf_event)) {
 		cout << dtmf_ev2char(dtmf_event) << endl;
 	} else {
 		cout << "invalid DTMF telephone event (" << (int)dtmf_event << endl;
@@ -2955,22 +2954,22 @@ void t_userintf::cb_dtmf_detected(int line, char dtmf_event) {
 	cout.flush();
 }
 
-void t_userintf::cb_async_dtmf_detected(int line, char dtmf_event) {
+void t_userintf::cb_async_dtmf_detected(int line, t_dtmf_ev dtmf_event) {
 	if (line >= NUM_USER_LINES) return;
 	
 	t_event_ui *event = new t_event_ui(TYPE_UI_CB_DTMF_DETECTED);
 	MEMMAN_NEW(event);
 	
 	event->set_line(line);
-	event->set_dtmf_event(dtmf_event);	
+	event->set_dtmf_event(dtmf_event);
 	evq_ui_events.push(event);
 }
 
-void t_userintf::cb_send_dtmf(int line, char dtmf_event) {
+void t_userintf::cb_send_dtmf(int line, t_dtmf_ev dtmf_event) {
 	// No feed back in CLI
 }
 
-void t_userintf::cb_async_send_dtmf(int line, char dtmf_event) {
+void t_userintf::cb_async_send_dtmf(int line, t_dtmf_ev dtmf_event) {
 	t_event_ui *event = new t_event_ui(TYPE_UI_CB_SEND_DTMF);
 	MEMMAN_NEW(event);
 	
@@ -3063,7 +3062,7 @@ void t_userintf::cb_refer_result_success(int line) {
 	if (line >= NUM_USER_LINES) return;
 	
 	cout << endl;
-	cout << "Line " << line + 1 << ": call succesfully referred.\n";
+	cout << "Line " << line + 1 << ": call successfully referred.\n";
 	cout << endl;
 	cout.flush();
 }
@@ -3097,7 +3096,7 @@ void t_userintf::cb_call_referred(t_user *user_config, int line, t_request *r) {
 	cout << endl;
 
 	if (r->hdr_referred_by.is_populated()) {
-		cout << "Tranfer requested by ";
+		cout << "Transfer requested by ";
 		cout << format_sip_address(user_config, r->hdr_referred_by.display,
 			r->hdr_referred_by.uri);
 		cout << endl;
