@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #ifndef _USERINTF_H
@@ -270,10 +269,10 @@ public:
         virtual void cb_stop_tone(int line);
         virtual void cb_notify_call(int line, string from_party);
         virtual void cb_stop_call_notification(int line);
-	virtual void cb_dtmf_detected(int line, char dtmf_event);
-	virtual void cb_async_dtmf_detected(int line, char dtmf_event);
-	virtual void cb_send_dtmf(int line, char dtmf_event);
-	virtual void cb_async_send_dtmf(int line, char dtmf_event);
+	virtual void cb_dtmf_detected(int line, t_dtmf_ev dtmf_event);
+	virtual void cb_async_dtmf_detected(int line, t_dtmf_ev dtmf_event);
+	virtual void cb_send_dtmf(int line, t_dtmf_ev dtmf_event);
+	virtual void cb_async_send_dtmf(int line, t_dtmf_ev dtmf_event);
 	virtual void cb_dtmf_not_supported(int line);
 	virtual void cb_dtmf_supported(int line);
 	virtual void cb_line_state_changed(void);
